"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.privateApi = void 0;

var types = _interopRequireWildcard(require("@babel/types"));

var _constants = _interopRequireDefault(require("./constants"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

/**
 * Utils service for logging arguments.
 *
 * @private
 * @mixin
 */
var privateApi = {};
/**
 * Utils service for logging arguments sent to logger
 *
 * @mixin
 */

exports.privateApi = privateApi;
var service = {};
/**
 * Get default arguments for logging
 *
 * @param {Object} state - node state
 * @param {LogResourceObj} knownData - object with pre-determined data
 * @return {Array<String>} parameter names that represent a string
 */

privateApi.getDefault = function (state, knownData) {
  var _state$file$opts = state.file.opts,
      sourceFileName = _state$file$opts.sourceFileName,
      sourceMapTarget = _state$file$opts.sourceMapTarget;
  var sourceFile = sourceMapTarget || sourceFileName; // build first argument, will contain file name, line number and column number

  var firstArg = "[".concat(sourceFile, ":").concat(knownData.line, ":").concat(knownData.column, "]");
  return [types.stringLiteral(firstArg), types.stringLiteral(knownData.name)];
};
/**
 * Get function arguments that represent an Identifier
 *
 * @param {Object} path - node path
 * @return {Array<String>} parameter names that represent an Identifier
 */


privateApi.getFunctionArguments = function (path) {
  var _path$node = path.node;
  _path$node = _path$node === void 0 ? {} : _path$node;
  var _path$node$params = _path$node.params,
      params = _path$node$params === void 0 ? [] : _path$node$params;
  return params.filter(function (param) {
    return types.isIdentifier(param);
  }).map(function (param) {
    return param.name;
  });
};
/**
 * Get other arguments that should be added when logging
 *
 * @param {Object} path - node path
 * @param {LogResourceObj} knownData - object with pre-determined data
 * @return {Array<String>} parameter names that represent an Identifier
 */


privateApi.getOtherArguments = function (path, knownData) {
  var argumentsToAdd = [];
  var isCatchClause = types.isCatchClause(path);

  if (isCatchClause) {
    // for the catch we need to add the exception
    argumentsToAdd.push(path.node.param.name);
  } else if (knownData.name === _constants.default.MEMBER_EXPRESSION_CATCH) {
    // for a member expression that is catch we should add his arguments
    argumentsToAdd.push.apply(argumentsToAdd, _toConsumableArray(privateApi.getFunctionArguments(path)));
  }

  return argumentsToAdd.map(function (identifierName) {
    return types.identifier(identifierName);
  });
};
/**
 * Get arguments for the logger call that is inserted.
 *
 * @param {Object} path - node path
 * @param {Object} state - node state
 * @param {LogResourceObj} knownData - object with pre-determined data
 * @return {Array} args
 */


service.get = function (path, state, knownData) {
  return privateApi.getDefault(state, knownData).concat(privateApi.getOtherArguments(path, knownData));
}; // only for testing


var _default = service;
exports.default = _default;